﻿SET QUOTED_IDENTIFIER OFF;
GO
USE [UrgentOrdersManagement];
GO
IF SCHEMA_ID(N'dbo') IS NULL EXECUTE(N'CREATE SCHEMA [dbo]');
GO

-- --------------------------------------------------
-- Dropping existing FOREIGN KEY constraints
-- --------------------------------------------------

IF OBJECT_ID(N'[dbo].[FK_UrgentOrder_Answer]', 'F') IS NOT NULL
    ALTER TABLE [dbo].[AnswerSet] DROP CONSTRAINT [FK_UrgentOrder_Answer];
GO

-- --------------------------------------------------
-- Dropping existing tables
-- --------------------------------------------------

IF OBJECT_ID(N'[dbo].[UrgentOrderSet]', 'U') IS NOT NULL
    DROP TABLE [dbo].[UrgentOrderSet];
GO
IF OBJECT_ID(N'[dbo].[AnswerSet]', 'U') IS NOT NULL
    DROP TABLE [dbo].[AnswerSet];
GO

-- --------------------------------------------------
-- Creating all tables
-- --------------------------------------------------

-- Creating table 'UrgentOrderSet'
CREATE TABLE [dbo].[UrgentOrderSet] (
    [UrgentOrderId] int IDENTITY(1,1) NOT NULL,
    [OrderNbr] int  NOT NULL,
    [OrderArticle] int  NOT NULL,
    [OrderQuantity] int  NOT NULL,
    [OrderDescription] nvarchar(max)  NOT NULL,
    [Remarks] nvarchar(max)  NULL,
    [ConfirmationDate] datetime  NULL,
    [WorkCenter] nvarchar(max)  NULL
);
GO

-- Creating table 'AnswerSet'
CREATE TABLE [dbo].[AnswerSet] (
    [AnswerId] int IDENTITY(1,1) NOT NULL,
    [AnswerFk] int  NOT NULL,
    [Contact] nvarchar(max)  NULL,
    [RequestDate] datetime  NULL,
    [AnswerText] nvarchar(max)  NULL
);
GO

-- --------------------------------------------------
-- Creating all PRIMARY KEY constraints
-- --------------------------------------------------

-- Creating primary key on [UrgentOrderId] in table 'UrgentOrderSet'
ALTER TABLE [dbo].[UrgentOrderSet]
ADD CONSTRAINT [PK_UrgentOrderSet]
    PRIMARY KEY CLUSTERED ([UrgentOrderId] ASC);
GO

-- Creating primary key on [AnswerId] in table 'AnswerSet'
ALTER TABLE [dbo].[AnswerSet]
ADD CONSTRAINT [PK_AnswerSet]
    PRIMARY KEY CLUSTERED ([AnswerId] ASC);
GO

-- --------------------------------------------------
-- Creating all FOREIGN KEY constraints
-- --------------------------------------------------

-- Creating foreign key on [AnswerFk] in table 'AnswerSet'
ALTER TABLE [dbo].[AnswerSet]
ADD CONSTRAINT [FK_UrgentOrder_Answer]
    FOREIGN KEY ([AnswerFk])
    REFERENCES [dbo].[UrgentOrderSet]
        ([UrgentOrderId])
    ON DELETE CASCADE ON UPDATE NO ACTION;
GO

-- Creating non-clustered index for FOREIGN KEY 'FK_UrgentOrder_Answer'
CREATE INDEX [IX_FK_UrgentOrder_Answer]
ON [dbo].[AnswerSet]
    ([AnswerFk]);
GO
